Browsing by Author "Wu, Sung-Ming"
Now showing 1 - 2 of 2
- Results Per Page
- Sort Options
Item type:Item, Adaptive Write Interference Management with Efficient Mapping for Shingled Recording Disks(2019-01-01) ;Lee, Ming-Chang ;Chang, Li-Pin ;Wu, Sung-Ming ;Yui, Wei-Shang資訊工程學系Shingled Magnetic Recording (SMR) is a novel disk technology that partially overlaps adjacent disk tracks for high storage density. The partial overlap creates write interference between tracks, and overwriting a track requires to rewrite all its downstream tracks. Inspired by the highly unequal track modify probabilities under real workloads, we propose moving frequently modified tracks toward a downstream, deliberately reserved track, called a guard track, to reduce the extent of write interference. We also introduce a low-cost, seek-optimized scheme for efficient logical-to-physical address mapping. Experimental results showed that our approach outperformed a popular design by 54% and 55% on average in terms of write response time and total disk writes, respectively.Item type:Item, KVSSD: Close Integration of LSM Trees and Flash Translation Layer for Write-Efficient KV Store(2018-01-01) ;Wu, Sung-Ming ;Lin, Kai-Hsiang ;Chang, Li-Pin ;資訊工程學系Department of Computer ScienceLog-Structured-Merge (LSM) trees are a write-optimized data structure for lightweight, high-performance Key-Value (KV) store. Solid State Disks (SSDs) provide acceleration of KV operations on LSM trees. However, this hierarchical design involves multiple software layers, including the LSM tree, host file system, and Flash Translation Layer (FTL), causing cascading write amplifications. We propose KVSSD, a close integration of LSM trees and the FTL, to manage write amplifications from different layers. KVSSD exploits the FTL, mapping mechanism to implement copy-free compaction of LSM trees, and it enables direct data allocation in Hash memory for efficient garbage collection. In our experiments, compared to the hierarchical design, our KVSSD reduced the write amplification by 88% and improved the throughput by 347%.